import numpy as np
from scipy.optimize import curve_fit
from trtwn.math import gauss

def fit_gauss(x, y):

    # Find starting parameters
    _sum = np.sum(y)
    peak = np.max(y)
    mean = np.sum(x * y)/_sum
    sigma = np.sqrt(sum(y*(x-mean)**2)/_sum)
    offset = y[0]

    # Fit gaussian curve to y
    return curve_fit(gauss, x, y, p0=[peak,mean,sigma,offset])


from PyQt5.QtWidgets import QWidget, QVBoxLayout, QSizePolicy
import matplotlib as mpl
mpl.use('QT5Agg')
from matplotlib import pylab as plt
from matplotlib.figure import Figure
from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg

class MplCanvas(FigureCanvasQTAgg):
    def __init__(self):
        self.fig = Figure()
        self.ax = self.fig.add_subplot(111)
        FigureCanvasQTAgg.__init__(self, self.fig)
        FigureCanvasQTAgg.setSizePolicy(
            self, QSizePolicy.Expanding, QSizePolicy.Expanding)
        FigureCanvasQTAgg.updateGeometry(self)

class MplWidget(QWidget):
    def __init__(self, parent=None):
        QWidget.__init__(self, parent)
        self.canvas = MplCanvas()
        self.vbl = QVBoxLayout()
        self.vbl.addWidget(self.canvas)
        self.setLayout(self.vbl)